==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/types/MasterMonster.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
namespace com.db4o.test.types {

   public class MasterMonster: RTest {
      
      public MasterMonster() : base() {
      }
      public Object[] ooo;
      
      public override void set(int ver) {
         Object[] classes = allClassesButThis();
         ooo = new Object[classes.Length];
         for (int i = 0; i < classes.Length; i++) {
            try {
               {
                  RTestable test = (RTestable)classes[i];
               }
            }  catch (Exception e) {
               {
                  throw new RuntimeException("MasterMonster instantiation failed.");
               }
            }
         }
      }
      
      internal Object[] allClassesButThis() {
         Object[] all = Regression.allClasses();
         Object[] classes = new Object[all.Length - 1];
         j4o.lang.JavaSystem.arraycopy(all, 0, classes, 0, all.Length - 1);
         return classes;
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/types/MasterMonster.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
namespace com.db4o.test.types {

   public class MasterMonster: RTest {
      
      public MasterMonster() : base() {
      }
      public Object[] ooo;
      
      public override void Set(int ver) {
         Object[] classes = AllClassesButThis();
         ooo = new Object[classes.Length];
         for (int i = 0; i < classes.Length; i++) {
            try {
               {
                  RTestable test = (RTestable)classes[i];
               }
            }  catch (Exception e) {
               {
                  throw new RuntimeException("MasterMonster instantiation failed.");
               }
            }
         }
      }
      
      internal Object[] AllClassesButThis() {
         Object[] all = Regression.AllClasses();
         Object[] classes = new Object[all.Length - 1];
		 System.Array.Copy(all, 0, classes, 0, all.Length - 1);
         return classes;
      }
   }
}
